use strict;

sub mkprint
{
    my $line = shift;
    print MAKE $line."\n";
}
sub mkprinttab
{
    my $line = shift;
    print MAKE "\t".$line."\n";
}
sub askval
{
    my $value = shift;
    my $title = shift;
    my $val;
    print "$title [$$value]: ";
    $val = <STDIN>;
    chomp($val);
    if ($val)
    {
	$$value = $val;
    }
}

my $version = `mynews -v`;
if ($version =~ /MyNews website version (\S+)/m)
{
    if ($1 < 1.1)
    {
	print "\n";
	print "*** Error: MyCMS requires at least MyNews website 1.1 to be installed ***\n";
	print "\n";
	exit;
    }
    if ($version =~ /MN::CMS module version (\S+)/m)
    {
	if ($1 < 1.0)
	{
	    print "\n";
	    print "*** Error: MyCMS requires at least MN::CMS module 1.0 to be installed ***\n";
	    print "\n";
	    exit;
	}
    }
    else
    {
	print "\n";
	print "*** Error: MyCMS requires MN::CMS module to be installed ***\n";
	print "\n";
	exit;
    }
}
else
{
    print "\n";
    print "*** Error: MyCMS requires MyNews website to be installed ***\n";
    print "\n";
    exit;
}

my $conf_path = '/etc';

askval(\$conf_path, "Conf dir");

open(CONF, "$conf_path/mynews.conf") || die "Unable to open MyNews conf file $conf_path/mynews.conf";
my $line;
my $webdir = "";
my $weburl = "";
my $pubdir = "";
my $puburl = "";
my $dbtype = "";
my $dbname = "";
my $dbuser = "";
my $key;
my $val;
while ($line = <CONF>)
{
    if ($line =~ /^\s*(\S+)\s*=\s*(.*)$/)
    {
	$key = $1;
	$val = $2;
	if ($key eq 'type')
	{
	    $dbtype = $val;
	}
	elsif ($key eq 'database')
	{
	    $dbname = $val;
	}
	elsif ($key eq 'user')
	{
	    $dbuser = $val;
	}
	elsif ($key eq 'webdir')
	{
	    $webdir = $val;
	}
	elsif ($key eq 'weburl')
	{
	    $weburl = $val;
	}
	elsif ($key eq 'pubdir')
	{
	    $pubdir = $val;
	}
	elsif ($key eq 'puburl')
	{
	    $puburl = $val;
	}
    }
}
close(CONF);

my @st = stat("$conf_path/mynews.conf");
my $mnuser = getpwuid($st[4]);
my $mngroup = getgrgid($st[5]);
if (!defined $mnuser)
{
    $mnuser = $st[4];
}
if (!defined $mngroup)
{
    $mngroup = $st[5];
}

my $lsl = `ls lang/*/name`;
my @langs = $lsl =~ /lang\/([^\/]+)\//mg;
my $lang;

print "Writing Makefile for mycms\n";
open(MAKE, ">Makefile");

mkprint('# Makefile to install mycms');
mkprint();
mkprint('DB_TYPE = '.$dbtype);
mkprint('DB_NAME = '.$dbname);
mkprint('DB_USER = '.$dbuser);
mkprint('WEB_DIR = '.$webdir."/cms");
mkprint('WEB_URL = '.$weburl."/cms");
if ($pubdir)
{
    mkprint('PUB_DIR = '.$pubdir."/cms");
    mkprint('PUB_URL = '.$puburl."/cms");
}
mkprint('MN_USER = '.$mnuser);
mkprint('MN_GROUP = '.$mngroup);
mkprint();
mkprint('BUILD_DIR = build');
mkprint('AUTH_HTACCESS = authhtaccess');
mkprint('MOD_HTACCESS = modhtaccess');
mkprint('ADM_HTACCESS = admhtaccess');
mkprint('MAKEFILE = Makefile');
mkprint('MAKEFILE_OLD = Makefile.old');
mkprint('MNWWW = t/mycms.t');
mkprint('MYDOC = mydoc');
mkprint();
mkprint('PERL = '.$^X);
mkprint('MYNEWS = mynews');
mkprint('SHELL = /bin/sh');
mkprint('NOOP = $(SHELL) -c true');
mkprint('NOECHO = @');
mkprint('ECHO = echo');
mkprint('ECHON = echo -n');
mkprint('CHMOD = chmod');
mkprint('CHOWN = chown');
mkprint('CHGRP = chgrp');
mkprint('CP = cp');
mkprint('MV = mv');
mkprint('MKDIR = mkdir -p');
mkprint('LN_SF = ln -sf');
mkprint('RM_F = rm -f');
mkprint('RM_RF = rm -rf');
mkprint('PRINT_UHT = echo >> $(BUILD_DIR)/$(AUTH_HTACCESS)');
mkprint('PRINT_MHT = echo >> $(BUILD_DIR)/$(MOD_HTACCESS)');
mkprint('PRINT_AHT = echo >> $(BUILD_DIR)/$(ADM_HTACCESS)');
mkprint('PRINT_CONF = echo >> '.$conf_path.'/mynews.conf');
mkprint();
mkprint('.SUFFIXES: .html .xml');
mkprint('.xml.html :');
mkprinttab('$(MYDOC) $<');
mkprint();
mkprint('all : $(BUILD_DIR) $(BUILD_DIR)/$(AUTH_HTACCESS) $(BUILD_DIR)/$(MOD_HTACCESS) $(BUILD_DIR)/$(ADM_HTACCESS) doc');
mkprinttab('$(NOECHO) $(ECHO)');
mkprinttab('$(NOECHO) $(ECHO) MyCMS website built successfully');
mkprinttab('$(NOECHO) $(ECHO)');
mkprint();
mkprint('cleandoc :');
mkprinttab('$(RM_F) lang/*/*.html');
mkprint();
mkprint('clean : cleandoc');
mkprinttab('$(RM_RF) $(BUILD_DIR)');
mkprinttab('$(RM_F) lang/*/*.html');
mkprinttab('$(MV) $(MAKEFILE) $(MAKEFILE_OLD)');
mkprint();
mkprint('realclean : clean');
mkprinttab('$(RM_F) $(MAKEFILE_OLD)');
mkprint();
mkprint('$(BUILD_DIR) :');
mkprinttab('$(MKDIR) $(BUILD_DIR)');
mkprint();
mkprint('$(BUILD_DIR)/$(AUTH_HTACCESS) :');
mkprinttab('$(PRINT_UHT) \'AuthName "MyCMS"\'');
mkprinttab('$(PRINT_UHT) "AuthType Basic"');
if ($dbtype eq 'pgsql')
{
    mkprinttab('$(PRINT_UHT) "Auth_PG_host localhost"');
    mkprinttab('$(PRINT_UHT) "Auth_PG_port 5432"');
    mkprinttab('$(PRINT_UHT) "Auth_PG_user $(DB_USER)"');
    mkprinttab('$(PRINT_UHT) "Auth_PG_database $(DB_NAME)"');
    mkprinttab('$(PRINT_UHT) "Auth_PG_pwd_table mnuser"');
    mkprinttab('$(PRINT_UHT) "Auth_PG_grp_table mnusergroup"');
    mkprinttab('$(PRINT_UHT) "Auth_PG_uid_field login"');
    mkprinttab('$(PRINT_UHT) "Auth_PG_gid_field groupid"');
    mkprinttab('$(PRINT_UHT) "Auth_PG_pwd_field password"');
}
elsif ($dbtype eq 'mysql')
{
    mkprinttab('$(PRINT_UHT) "AuthGroupFile /dev/null"');
    mkprinttab('$(PRINT_UHT) "AuthMySQLHost localhost"');
    mkprinttab('$(PRINT_UHT) "AuthMySQLUser $(DB_USER)"');
    mkprinttab('$(PRINT_UHT) "AuthMySQLDB $(DB_NAME)"');
    mkprinttab('$(PRINT_UHT) "AuthMySQLUserTable mnuser"');
    mkprinttab('$(PRINT_UHT) "AuthMySQLGroupTable mnusergroup"');
    mkprinttab('$(PRINT_UHT) "AuthMySQLNameField login"');
    mkprinttab('$(PRINT_UHT) "AuthMySQLGroupField groupid"');
    mkprinttab('$(PRINT_UHT) "AuthMySQLPasswordField password"');
}
mkprinttab('$(PRINT_UHT) "<LIMIT GET POST>"');
mkprinttab('$(PRINT_UHT) "Require group auth"');
mkprinttab('$(PRINT_UHT) "</LIMIT>"');
mkprint();
mkprint('$(BUILD_DIR)/$(MOD_HTACCESS) :');
mkprinttab('$(PRINT_MHT) \'AuthName "MyCMS"\'');
mkprinttab('$(PRINT_MHT) "AuthType Basic"');
if ($dbtype eq 'pgsql')
{
    mkprinttab('$(PRINT_MHT) "Auth_PG_host localhost"');
    mkprinttab('$(PRINT_MHT) "Auth_PG_port 5432"');
    mkprinttab('$(PRINT_MHT) "Auth_PG_user $(DB_USER)"');
    mkprinttab('$(PRINT_MHT) "Auth_PG_database $(DB_NAME)"');
    mkprinttab('$(PRINT_MHT) "Auth_PG_pwd_table mnuser"');
    mkprinttab('$(PRINT_MHT) "Auth_PG_grp_table mnusergroup"');
    mkprinttab('$(PRINT_MHT) "Auth_PG_uid_field login"');
    mkprinttab('$(PRINT_MHT) "Auth_PG_gid_field groupid"');
    mkprinttab('$(PRINT_MHT) "Auth_PG_pwd_field password"');
}
elsif ($dbtype eq 'mysql')
{
    mkprinttab('$(PRINT_MHT) "AuthGroupFile /dev/null"');
    mkprinttab('$(PRINT_MHT) "AuthMySQLHost localhost"');
    mkprinttab('$(PRINT_MHT) "AuthMySQLUser $(DB_USER)"');
    mkprinttab('$(PRINT_MHT) "AuthMySQLDB $(DB_NAME)"');
    mkprinttab('$(PRINT_MHT) "AuthMySQLUserTable mnuser"');
    mkprinttab('$(PRINT_MHT) "AuthMySQLGroupTable mnusergroup"');
    mkprinttab('$(PRINT_MHT) "AuthMySQLNameField login"');
    mkprinttab('$(PRINT_MHT) "AuthMySQLGroupField groupid"');
    mkprinttab('$(PRINT_MHT) "AuthMySQLPasswordField password"');
}
mkprinttab('$(PRINT_MHT) "<LIMIT GET POST>"');
mkprinttab('$(PRINT_MHT) "Require group mod"');
mkprinttab('$(PRINT_MHT) "</LIMIT>"');
mkprint();
mkprint('$(BUILD_DIR)/$(ADM_HTACCESS) :');
mkprinttab('$(PRINT_AHT) \'AuthName "MyCMS"\'');
mkprinttab('$(PRINT_AHT) "AuthType Basic"');
if ($dbtype eq 'pgsql')
{
    mkprinttab('$(PRINT_AHT) "Auth_PG_host localhost"');
    mkprinttab('$(PRINT_AHT) "Auth_PG_port 5432"');
    mkprinttab('$(PRINT_AHT) "Auth_PG_user $(DB_USER)"');
    mkprinttab('$(PRINT_AHT) "Auth_PG_database $(DB_NAME)"');
    mkprinttab('$(PRINT_AHT) "Auth_PG_pwd_table mnuser"');
    mkprinttab('$(PRINT_AHT) "Auth_PG_grp_table mnusergroup"');
    mkprinttab('$(PRINT_AHT) "Auth_PG_uid_field login"');
    mkprinttab('$(PRINT_AHT) "Auth_PG_gid_field groupid"');
    mkprinttab('$(PRINT_AHT) "Auth_PG_pwd_field password"');
}
elsif ($dbtype eq 'mysql')
{
    mkprinttab('$(PRINT_AHT) "AuthGroupFile /dev/null"');
    mkprinttab('$(PRINT_AHT) "AuthMySQLHost localhost"');
    mkprinttab('$(PRINT_AHT) "AuthMySQLUser $(DB_USER)"');
    mkprinttab('$(PRINT_AHT) "AuthMySQLDB $(DB_NAME)"');
    mkprinttab('$(PRINT_AHT) "AuthMySQLUserTable mnuser"');
    mkprinttab('$(PRINT_AHT) "AuthMySQLGroupTable mnusergroup"');
    mkprinttab('$(PRINT_AHT) "AuthMySQLNameField login"');
    mkprinttab('$(PRINT_AHT) "AuthMySQLGroupField groupid"');
    mkprinttab('$(PRINT_AHT) "AuthMySQLPasswordField password"');
}
mkprinttab('$(PRINT_AHT) "<LIMIT GET POST>"');
mkprinttab('$(PRINT_AHT) "Require group admin"');
mkprinttab('$(PRINT_AHT) "</LIMIT>"');

mkprint();
mkprint('dbinit :');
mkprinttab('$(MYNEWS) -ctb mnprivilege dbinit db/mycms.$(DB_TYPE)');
mkprint();
mkprint('dbreset :');
mkprinttab('$(MYNEWS) dbinit db/drop.$(DB_TYPE)');

mkprint();
mkprint('doc :'.join("", map {" doc_$_"} @langs));
mkprinttab('$(NOECHO) $(NOOP)');
mkprint();
mkprint('install_doc :'.join("", map {" install_doc_$_"} @langs));
mkprinttab('$(NOECHO) $(NOOP)');
mkprint();
my $instline = 'install : all dbinit $(WEB_DIR) install_scripts install_auth install_mod install_adm install_css install_img install_lang install_doc';
if ($pubdir)
{
    $instline .= " installpub";
}
mkprint($instline);
mkprinttab('$(NOECHO) $(ECHO)');
mkprinttab('$(NOECHO) $(ECHO) MyNews website installed successfully');
mkprinttab('$(NOECHO) $(ECHO)');
mkprint();
mkprint('$(WEB_DIR) :');
mkprinttab('$(MKDIR) $(WEB_DIR)');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)');
mkprinttab('$(CHMOD) 0750  $(WEB_DIR)');
mkprint();
mkprint('$(WEB_DIR)/auth :');
mkprinttab('$(MKDIR) $(WEB_DIR)/auth');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/auth');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/auth');
mkprinttab('$(CHMOD) 0750  $(WEB_DIR)/auth');
mkprint();
mkprint('$(WEB_DIR)/mod :');
mkprinttab('$(MKDIR) $(WEB_DIR)/mod');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/mod');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/mod');
mkprinttab('$(CHMOD) 0750  $(WEB_DIR)/mod');
mkprint();
mkprint('$(WEB_DIR)/adm :');
mkprinttab('$(MKDIR) $(WEB_DIR)/adm');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/adm');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/adm');
mkprinttab('$(CHMOD) 0750  $(WEB_DIR)/adm');
mkprint();
mkprint('$(WEB_DIR)/css :');
mkprinttab('$(MKDIR) $(WEB_DIR)/css');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/css');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/css');
mkprinttab('$(CHMOD) 0750  $(WEB_DIR)/css');
mkprint();
mkprint('$(WEB_DIR)/img :');
mkprinttab('$(MKDIR) $(WEB_DIR)/img');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/img');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/img');
mkprinttab('$(CHMOD) 0750  $(WEB_DIR)/img');
mkprint();
mkprint('$(WEB_DIR)/img/mini : $(WEB_DIR)/img');
mkprinttab('$(MKDIR) $(WEB_DIR)/img/mini');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/img/mini');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/img/mini');
mkprinttab('$(CHMOD) 0770  $(WEB_DIR)/img/mini');
mkprint();
mkprint('$(WEB_DIR)/img/maxi : $(WEB_DIR)/img');
mkprinttab('$(MKDIR) $(WEB_DIR)/img/maxi');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/img/maxi');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/img/maxi');
mkprinttab('$(CHMOD) 0770  $(WEB_DIR)/img/maxi');
mkprint();
mkprint('$(WEB_DIR)/img/tmp : $(WEB_DIR)/img');
mkprinttab('$(MKDIR) $(WEB_DIR)/img/tmp');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/img/tmp');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/img/tmp');
mkprinttab('$(CHMOD) 0770  $(WEB_DIR)/img/tmp');
mkprint();
mkprint('$(WEB_DIR)/lang :');
mkprinttab('$(MKDIR) $(WEB_DIR)/lang');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/lang');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/lang');
mkprinttab('$(CHMOD) 0750  $(WEB_DIR)/lang');
mkprint();
mkprint('install_scripts : $(BUILD_DIR)/$(HTACCESS)');
mkprinttab('$(CP) *.cgi $(WEB_DIR)');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/*.cgi');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/*.cgi');
mkprinttab('$(CHMOD) 0750 $(WEB_DIR)/*.cgi');
mkprinttab('$(CP) version.txt $(WEB_DIR)');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/version.txt');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/version.txt');
mkprinttab('$(CHMOD) 0640 $(WEB_DIR)/version.txt');
mkprint();
mkprint('$(WEB_DIR)/auth/.htaccess :');
mkprinttab('$(CP) $(BUILD_DIR)/$(AUTH_HTACCESS) $(WEB_DIR)/auth/.htaccess');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/auth/.htaccess');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/auth/.htaccess');
mkprinttab('$(CHMOD) 0640 $(WEB_DIR)/auth/.htaccess');
mkprint();
mkprint('install_auth : $(WEB_DIR)/auth $(BUILD_DIR)/$(AUTH_HTACCESS) $(WEB_DIR)/auth/.htaccess');
mkprinttab('$(CP) auth/*.cgi $(WEB_DIR)/auth');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/auth/*.cgi');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/auth/*.cgi');
mkprinttab('$(CHMOD) 0750 $(WEB_DIR)/auth/*.cgi');
mkprint();
mkprint('$(WEB_DIR)/mod/.htaccess :');
mkprinttab('$(CP) $(BUILD_DIR)/$(MOD_HTACCESS) $(WEB_DIR)/mod/.htaccess');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/mod/.htaccess');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/mod/.htaccess');
mkprinttab('$(CHMOD) 0640 $(WEB_DIR)/mod/.htaccess');
mkprint();
mkprint('install_mod : $(WEB_DIR)/mod $(BUILD_DIR)/$(MOD_HTACCESS) $(WEB_DIR)/mod/.htaccess');
mkprinttab('$(CP) mod/*.cgi $(WEB_DIR)/mod');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/mod/*.cgi');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/mod/*.cgi');
mkprinttab('$(CHMOD) 0750 $(WEB_DIR)/mod/*.cgi');
mkprint();
mkprint('$(WEB_DIR)/adm/.htaccess :');
mkprinttab('$(CP) $(BUILD_DIR)/$(ADM_HTACCESS) $(WEB_DIR)/adm/.htaccess');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/adm/.htaccess');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/adm/.htaccess');
mkprinttab('$(CHMOD) 0640 $(WEB_DIR)/adm/.htaccess');
mkprint();
mkprint('install_adm : $(WEB_DIR)/adm $(BUILD_DIR)/$(ADM_HTACCESS) $(WEB_DIR)/adm/.htaccess');
mkprinttab('$(CP) adm/*.cgi $(WEB_DIR)/adm');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/adm/*.cgi');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/adm/*.cgi');
mkprinttab('$(CHMOD) 0750 $(WEB_DIR)/adm/*.cgi');
mkprint();
mkprint('install_css : $(WEB_DIR)/css');
mkprinttab('$(CP) css/*.css $(WEB_DIR)/css');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/css/*.css');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/css/*.css');
mkprinttab('$(CHMOD) 0750 $(WEB_DIR)/css/*.css');
mkprint();
mkprint('install_img : $(WEB_DIR)/img $(WEB_DIR)/img/mini $(WEB_DIR)/img/tmp $(WEB_DIR)/img/maxi');
mkprinttab('$(CP) img/*.png $(WEB_DIR)/img');
mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/img/*.png');
mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/img/*.png');
mkprinttab('$(CHMOD) 0640 $(WEB_DIR)/img/*.png');
mkprint();
mkprint('install_lang : $(WEB_DIR)/lang'.join("", map {" install_lang_$_"} @langs));
mkprinttab('$(NOECHO) $(NOOP)');
mkprint();
foreach $lang (@langs)
{
    mkprint('$(WEB_DIR)/lang/'.$lang.' :');
    mkprinttab('$(MKDIR) $(WEB_DIR)/lang/'.$lang);
    mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/lang/'.$lang);
    mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/lang/'.$lang);
    mkprinttab('$(CHMOD) 0750  $(WEB_DIR)/lang/'.$lang);
    mkprint();
    mkprint('doc_'.$lang.' : $(patsubst %.xml,%.html,$(wildcard lang/'.$lang.'/*.xml))');
    mkprinttab('$(NOECHO) $(NOOP)');
    mkprint();
    mkprint('install_lang_'.$lang.' : $(WEB_DIR)/lang/'.$lang);
    mkprinttab('$(CP) lang/'.$lang.'/messages $(WEB_DIR)/lang/'.$lang);
    mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/lang/'.$lang.'/messages');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/lang/'.$lang.'/messages');
    mkprinttab('$(CHMOD) 0640  $(WEB_DIR)/lang/'.$lang.'/messages');
    mkprinttab('$(CP) lang/'.$lang.'/name $(WEB_DIR)/lang/'.$lang);
    mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/lang/'.$lang.'/name');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/lang/'.$lang.'/name');
    mkprinttab('$(CHMOD) 0640  $(WEB_DIR)/lang/'.$lang.'/name');
    mkprint();
    mkprint('install_doc_'.$lang.' : install_lang_'.$lang);
    mkprinttab('$(CP) lang/'.$lang.'/*.html $(WEB_DIR)/lang/'.$lang);
    mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/lang/'.$lang.'/*.html');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/lang/'.$lang.'/*.html');
    mkprinttab('$(CHMOD) 0640  $(WEB_DIR)/lang/'.$lang.'/*.html');
    mkprinttab('$(CP) lang/'.$lang.'/index.cgi $(WEB_DIR)/lang/'.$lang);
    mkprinttab('$(CHOWN) $(MN_USER) $(WEB_DIR)/lang/'.$lang.'/index.cgi');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(WEB_DIR)/lang/'.$lang.'/index.cgi');
    mkprinttab('$(CHMOD) 0750  $(WEB_DIR)/lang/'.$lang.'/index.cgi');
    mkprint();
}

if ($pubdir)
{
    mkprint('installpub_doc :'.join("", map {" installpub_doc_$_"} @langs));
    mkprinttab('$(NOECHO) $(NOOP)');
    mkprint();
    mkprint('installpub : all $(PUB_DIR) installpub_scripts installpub_css installpub_img installpub_lang installpub_doc');
    mkprinttab('$(NOECHO) $(NOOP)');
    mkprint();
    mkprint('$(PUB_DIR) :');
    mkprinttab('$(MKDIR) $(PUB_DIR)');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)');
    mkprinttab('$(CHMOD) 0750  $(PUB_DIR)');
    mkprint();
    mkprint('$(PUB_DIR)/css :');
    mkprinttab('$(MKDIR) $(PUB_DIR)/css');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/css');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/css');
    mkprinttab('$(CHMOD) 0750  $(PUB_DIR)/css');
    mkprint();
    mkprint('$(PUB_DIR)/img :');
    mkprinttab('$(MKDIR) $(PUB_DIR)/img');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/img');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/img');
    mkprinttab('$(CHMOD) 0750  $(PUB_DIR)/img');
    mkprint();
    mkprint('$(PUB_DIR)/img/mini : $(PUB_DIR)/img');
    mkprinttab('$(LN_SF) $(WEB_DIR)/img/maxi $(PUB_DIR)/img/maxi');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/img/mini');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/img/mini');
    mkprinttab('$(CHMOD) 0750  $(PUB_DIR)/img/mini');
    mkprint();
    mkprint('$(PUB_DIR)/img/maxi : $(PUB_DIR)/img');
    mkprinttab('$(LN_SF) $(WEB_DIR)/img/maxi $(PUB_DIR)/img/maxi');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/img/maxi');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/img/maxi');
    mkprinttab('$(CHMOD) 0750  $(PUB_DIR)/img/maxi');
    mkprint();
    mkprint('$(PUB_DIR)/lang :');
    mkprinttab('$(MKDIR) $(PUB_DIR)/lang');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/lang');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/lang');
    mkprinttab('$(CHMOD) 0750  $(PUB_DIR)/lang');
    mkprint();
    mkprint('installpub_scripts :');
    mkprinttab('$(CP) *.cgi $(PUB_DIR)');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/*.cgi');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/*.cgi');
    mkprinttab('$(CHMOD) 0750 $(PUB_DIR)/*.cgi');
    mkprinttab('$(CP) version.txt $(PUB_DIR)');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/version.txt');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/version.txt');
    mkprinttab('$(CHMOD) 0640 $(PUB_DIR)/version.txt');
    mkprint();
    mkprint('installpub_css : $(PUB_DIR)/css');
    mkprinttab('$(CP) css/*.css $(PUB_DIR)/css');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/css/*.css');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/css/*.css');
    mkprinttab('$(CHMOD) 0750 $(PUB_DIR)/css/*.css');
    mkprint();
    mkprint('installpub_img : $(PUB_DIR)/img $(PUB_DIR)/img/mini $(PUB_DIR)/img/maxi');
    mkprinttab('$(CP) img/*.png $(PUB_DIR)/img');
    mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/img/*.png');
    mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/img/*.png');
    mkprinttab('$(CHMOD) 0640 $(PUB_DIR)/img/*.png');
    mkprint();
    mkprint('installpub_lang : $(PUB_DIR)/lang'.join("", map {" installpub_lang_$_"} @langs));
    mkprinttab('$(NOECHO) $(NOOP)');
    mkprint();
    foreach $lang (@langs)
    {
	mkprint('$(PUB_DIR)/lang/'.$lang.' :');
	mkprinttab('$(MKDIR) $(PUB_DIR)/lang/'.$lang);
	mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/lang/'.$lang);
	mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/lang/'.$lang);
	mkprinttab('$(CHMOD) 0750  $(PUB_DIR)/lang/'.$lang);
	mkprint();
	mkprint('installpub_lang_'.$lang.' : $(PUB_DIR)/lang/'.$lang);
	mkprinttab('$(CP) lang/'.$lang.'/messages $(PUB_DIR)/lang/'.$lang);
	mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/lang/'.$lang.'/messages');
	mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/lang/'.$lang.'/messages');
	mkprinttab('$(CHMOD) 0640  $(PUB_DIR)/lang/'.$lang.'/messages');
	mkprinttab('$(CP) lang/'.$lang.'/name $(PUB_DIR)/lang/'.$lang);
	mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/lang/'.$lang.'/name');
	mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/lang/'.$lang.'/name');
	mkprinttab('$(CHMOD) 0640  $(PUB_DIR)/lang/'.$lang.'/name');
	mkprint();
	mkprint('installpub_doc_'.$lang.' : installpub_lang_'.$lang);
	mkprinttab('$(CP) lang/'.$lang.'/*.html $(PUB_DIR)/lang/'.$lang);
	mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/lang/'.$lang.'/*.html');
	mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/lang/'.$lang.'/*.html');
	mkprinttab('$(CHMOD) 0640  $(PUB_DIR)/lang/'.$lang.'/*.html');
	mkprinttab('$(CP) lang/'.$lang.'/index.cgi $(PUB_DIR)/lang/'.$lang);
	mkprinttab('$(CHOWN) $(MN_USER) $(PUB_DIR)/lang/'.$lang.'/index.cgi');
	mkprinttab('$(CHGRP) $(MN_GROUP) $(PUB_DIR)/lang/'.$lang.'/index.cgi');
	mkprinttab('$(CHMOD) 0750  $(PUB_DIR)/lang/'.$lang.'/index.cgi');
	mkprint();
    }
}

mkprint('uninstall : dbreset');
mkprinttab('$(RM_RF) $(WEB_DIR)');
if ($pubdir)
{
    mkprinttab('$(RM_RF) $(PUB_DIR)');
}
mkprinttab('$(NOECHO) $(ECHO)');
mkprinttab('$(NOECHO) $(ECHO) MyCMS website uninstalled successfully');
mkprinttab('$(NOECHO) $(ECHO)');
mkprint();
mkprint('test :');
mkprinttab('$(PERL) $(MNWWW)');
mkprinttab('$(NOECHO) $(ECHO)');
mkprinttab('$(NOECHO) $(ECHO) MyCMS website tested successfully');
mkprinttab('$(NOECHO) $(ECHO)');

close(MAKE);
